@@ -356,7 +356,7 @@ work."
 			  (find-file (nth 1 rel-headings))
 			  (goto-char (nth 3 rel-headings))
 			  (org-id-get-create))))))
-    (if (not (eq major-mode 'message-mode))
+    (if (not (derived-mode-p 'message-mode 'mail-mode))
 	;; The message is already sent, so we're relying on whatever was
 	;; stored into `gnorb-gnus-message-info'.
 	(if (equal arg '(16))
@@ -364,7 +364,7 @@ work."
 	    unsent message.")
 	  (if arg
 	      (progn
-		(push (car rel-headings) gnorb-message-org-ids)
+		(push (caar rel-headings) gnorb-message-org-ids)
 		(gnorb-org-restore-after-send))
 	    (setq ref-ids (plist-get gnorb-gnus-message-info :refs))
 	    (if ref-ids
@@ -550,7 +550,7 @@ you'll stay in the Gnus summary buffer."
 		     :link ,link :date ,date :refs ,ref-msg-ids
 		     :group ,group))
     (gnorb-gnus-collect-all-attachments nil t)
-    (condition-case err
+    (unwind-protect
 	(if id
 	    (progn
 	      (delete-other-windows)
@@ -617,12 +617,9 @@ you'll stay in the Gnus summary buffer."
 		 (mail-header-id (gnus-data-header (gnus-data-find a)))
 		 tags))
 	      (gnus-summary-update-article a))))
-      (error
-       ;; If these are left populated after an error, it plays hell
-       ;; with future trigger processes.
-       (setq gnorb-gnus-message-info nil)
-       (setq gnorb-gnus-capture-attachments nil)
-       (signal (car err) (cdr err))))))
+      ;; No matter what, clear these two variables.
+      (setq gnorb-gnus-message-info nil)
+      (setq gnorb-gnus-capture-attachments nil))))
 
 ;;;###autoload
 (defun gnorb-gnus-quick-reply ()
@@ -703,50 +700,56 @@ sender:google.com subject:\"your search results\""
   (interactive
    (list (read-string "Registry search terms: " nil
 		      gnorb-registry-search-history)))
-  (let (parsed found this-pass term)
+  (let ((case-fold-search t)
+	parsed found this-pass term)
     (with-temp-buffer
       (insert search-string)
       (goto-char (point-min))
       (while (re-search-forward
-	      "\\([[:alpha:]]+\\):\\(\\(?:\\w+\\|\"[[:alpha:] ]+\"\\)\\)"
+	      "\\([[:alpha:]]+\\):\\(\\(?:[^\"[:blank:]]+\\|\"[^\"]+\"\\)\\)"
 	      (point-at-eol) t)
 	(push (cons (intern (match-string 1))
-		    (string-trim (match-string 2) "\"" "\""))
-	      parsed))
-      (dolist (sym (slot-value gnus-registry-db 'tracked))
-	(when (setq term (cdr-safe (assoc sym parsed)))
-	  (maphash
-	   (lambda (k v)
-	     (when (string-match-p term k)
-	       (setq this-pass (append v this-pass))))
-	   (gethash sym (slot-value gnus-registry-db 'tracker)))
-	  (setq found (if found
-			  (seq-intersection found this-pass)
-			this-pass)
-		this-pass nil)))
-      (if found
-	  (let* ((server (gnorb-gnus-find-gnorb-server))
-		 (artlist
-		  (mapcar
-		   (lambda (msg)
-		     (pcase-let ((`(,group . ,artno) (gnorb-msg-id-request-head
-						      msg)))
-		       (when (and artno (integerp artno) (> artno 0))
-			 (vector group artno 100))))
-		   (delq nil (delete-dups found))))
-		 (name (make-temp-name "registry messages"))
-		 (spec (list
-			(cons 'nnir-specs (list (cons 'nnir-query-spec
-						      `((query . "dummy")
-							(articles . ,artlist)))
-						(cons 'nnir-group-spec
-						      `((,server ,(list name))))))
-			(cons 'nnir-artlist nil))))
-	    (switch-to-buffer gnus-group-buffer)
-	    (gnus-group-read-ephemeral-group
-	     name `(nnir ,server) nil `(switch-to-buffer ,gnus-group-buffer)
-	     nil nil spec))
-	(message "No results found")))))
+		    (replace-regexp-in-string "\\`\"\\|\"\\'" ""
+					      (match-string 2)))
+	      parsed)))
+    (dolist (sym (slot-value gnus-registry-db 'tracked))
+      (when (setq term (cdr-safe (assoc sym parsed)))
+	(maphash
+	 (lambda (k v)
+	   (when (string-match-p term k)
+	     (setq this-pass (append v this-pass))))
+	 (gethash sym (slot-value gnus-registry-db 'tracker)))
+	(setq found (if found
+			(seq-intersection found this-pass)
+		      this-pass)
+	      this-pass nil)))
+    (if found
+	(let* ((server (gnorb-gnus-find-gnorb-server))
+	       (artlist
+		(delq
+		 nil
+		 (mapcar
+		  (lambda (msg)
+		    (pcase-let ((`(,group . ,artno)
+				 (gnorb-msg-id-request-head
+				  msg (car-safe
+				       (gnus-registry-get-id-key msg 'group)))))
+		      (when (and group artno (integerp artno) (> artno 0))
+			(vector group artno 100))))
+		  (delq nil (delete-dups found)))))
+	       (name "registry messages")
+	       (spec (list
+		      (cons 'nnir-specs (list (cons 'nnir-query-spec
+						    `((query . "dummy")
+						      (articles . ,artlist)))
+					      (cons 'nnir-group-spec
+						    `((,server ,(list name))))))
+		      (cons 'nnir-artlist nil))))
+	  (switch-to-buffer gnus-group-buffer)
+	  (gnus-group-read-ephemeral-group
+	   name `(nnir ,server) nil `(switch-to-buffer ,gnus-group-buffer)
+	   nil nil spec))
+      (message "No results found"))))
 
 ;;;###autoload
 (defun gnorb-gnus-tag-message (arg &optional tags)
